Qualitative color ramp derived from active branding. This ramp excludes Bootstrap's white, black, light and gray colors, which are typically used for textual elements.
Usage
brand.colors(x = NULL, omit = c("white", "black", "gray"), ...)Arguments
- x
Brand color name(s), skip to return the entire color palette
- omit
Brand colors to exclude from color ramp
- ...
Arguments passed on to
grDevices::colorRampPalettecolorscolors to interpolate; must be a valid argument to
col2rgb().biasa positive number. Higher values give more widely spaced colors at the high end.
spacea character string; interpolation in RGB or Lab color spaces.
interpolateuse spline or linear interpolation.
alphalogical: should alpha channel (opacity) values be returned? It is an error to give a true value if
spaceis specified.